Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1364)

Unified Diff: content/renderer/mus/render_widget_window_tree_client_factory.cc

Issue 2398783002: Rename a bunch of Mojo Application stuff to reference Services. (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/mus/render_widget_window_tree_client_factory.cc
diff --git a/content/renderer/mus/render_widget_window_tree_client_factory.cc b/content/renderer/mus/render_widget_window_tree_client_factory.cc
index 52923eae18d41c25301d88b596847b259b5a3fd5..848685452e4c89b9ec425ea8b41b49829168c461 100644
--- a/content/renderer/mus/render_widget_window_tree_client_factory.cc
+++ b/content/renderer/mus/render_widget_window_tree_client_factory.cc
@@ -15,7 +15,7 @@
#include "base/threading/thread_task_runner_handle.h"
#include "content/common/render_widget_window_tree_client_factory.mojom.h"
#include "content/public/common/connection_filter.h"
-#include "content/public/common/mojo_shell_connection.h"
+#include "content/public/common/service_manager_connection.h"
#include "content/renderer/mus/render_widget_mus_connection.h"
#include "mojo/public/cpp/bindings/binding_set.h"
#include "services/shell/public/cpp/interface_factory.h"
@@ -35,7 +35,7 @@ void BindMusConnectionOnMainThread(
connection->Bind(std::move(request));
}
// This object's lifetime is managed by MojoShellConnection because it's a
// registered with it.
class RenderWidgetWindowTreeClientFactoryImpl
: public ConnectionFilter,
@@ -82,7 +82,7 @@ class RenderWidgetWindowTreeClientFactoryImpl
} // namespace
void CreateRenderWidgetWindowTreeClientFactory(
- MojoShellConnection* connection) {
+ ServiceManagerConnection* connection) {
connection->AddConnectionFilter(
base::MakeUnique<RenderWidgetWindowTreeClientFactoryImpl>());
}
@@ -35,7 +35,7 @@ void BindMusConnectionOnMainThread(
connection->Bind(std::move(request));
}
-// This object's lifetime is managed by MojoShellConnection because it's a
+// This object's lifetime is managed by ServiceManagerConnection because it's a
// registered with it.
class RenderWidgetWindowTreeClientFactoryImpl
« no previous file with comments | « content/renderer/mus/render_widget_window_tree_client_factory.h ('k') | content/renderer/render_frame_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698